@@ -10,8 +10,7 @@ logging.basicConfig(format='%(levelname)-8s %(message)s',
                     level=logging.INFO)
 logger = logging.getLogger('cloudns')
 
-_t1 = logging.getLogger('requests')
-_t1.setLevel(logging.WARNING)
+logging.getLogger('requests').setLevel(logging.WARNING)
 
 # some defined zone and record status.
 
