@@ -5,14 +5,12 @@
 defines the Record class
 """
 
-from .base import *
+from .base import PENDING_ACTIVE, ACTIVE, PENDING_REMOVAL, CloudnsBadUsage
 
 
 class Record(object):
     """a record is a simple object with these attribute:
 
-    It represents a record in cloudns system.
-
     =======  ======================================================
     attr     description
     =======  ======================================================
@@ -29,6 +27,8 @@ class Record(object):
              1 means ACTIVE, 2 means PENDING_REMOVAL.
     =======  ======================================================
 
+    It represents a record in cloudns system.
+
     """
     RESERVED_ATTRIBUTES = ('rid', 'name', 'type', 'content', 'isp',
                            'ctime', 'z', 'ttl', 'prio', 'status')
@@ -49,6 +49,24 @@ class Record(object):
     def __str__(self):
         return str(self._params)
 
+    @staticmethod
+    def pretty_print_status(status):
+        status_map = {
+            PENDING_ACTIVE: "PENDING_ACTIVE",
+            ACTIVE: "ACTIVE",
+            PENDING_REMOVAL: "PENDING_REMOVAL"
+        }
+        return status_map.get(status, 'UNKNOWN (%s)' % (status,))
+
+    def pretty_print(self):
+        """print record in a human readable format.
+
+        """
+        return u"""\
+%s.%s\t%s\t%s\t%s\t%s\t%s\
+""" % (self.name, self.z, self.ttl, self.type, self.content, self.isp,
+       self.pretty_print_status(self.status))
+
     def update(self, **kwargs):
         """return a new Record with given values replaced.
 
