@@ -8,7 +8,10 @@ defines the User class
 import time
 
 from .utils import count_if
-from .base import *
+from .base import (CloudnsRuntimeError, CloudnsBadUsage,
+                   CloudnsServerError, RecordNotFound,
+                   DuplicateRecord, RecordNotReady,
+                   logger)
 from .record import Record
 from .zone import Zone
 
