@@ -27,6 +27,11 @@ class Zone(object):
         self.user = user
         self.zone = zone_name
 
+    @staticmethod
+    def create_zone(passport, token, zone_name):
+        from .user import User
+        return Zone(User(passport=passport, token=token), zone_name)
+
     def get_all_records(self, offset=0, limit=20):
         """get all records under this zone.
 
@@ -68,7 +73,7 @@ class Zone(object):
         """
         return self.user.get_records_by_name(self.zone, name)
 
-    def create_record(self, name, content, isp, type='A', ttl=300):
+    def create_record(self, name, content, isp, type='A', ttl=300):  # pylint: disable=W0622
         """create a new record.
 
         .. note::
